@@ -1,5 +1,3 @@
-from typing import Final
-
 from discord import Interaction
 from discord.app_commands import command
 from discord.ext.commands import Bot, Cog
@@ -7,10 +5,10 @@ from discord.ext.commands import Bot, Cog
 
 class Example(Cog):
     def __init__(self, bot: Bot) -> None:
-        self.bot: Final[Bot] = bot
+        self.bot = bot
 
     @command(description="Say hello.")
-    async def hello(self, interaction: Interaction):
+    async def hello(self, interaction: Interaction) -> None:
         await interaction.response.send_message(f"Hello {interaction.user.mention}!")
 
 
