@@ -1,11 +1,9 @@
-from typing import Final
-
 from naff import Client, Extension, InteractionContext, slash_command
 
 
 class Example(Extension):
     def __init__(self, bot: Client) -> None:
-        self.bot: Final[Client] = bot
+        self.bot = bot
 
     @slash_command(name="hello", description="Say hello.")
     async def hello(self, ctx: InteractionContext) -> None:
