@@ -1,12 +1,10 @@
-from typing import Final
-
 from nextcord import Interaction, slash_command
 from nextcord.ext.commands import Bot, Cog
 
 
 class Example(Cog):
     def __init__(self, bot: Bot) -> None:
-        self.bot: Final[Bot] = bot
+        self.bot = bot
 
     @slash_command(description="Say hello.")
     async def hello(self, interaction: Interaction) -> None:
