@@ -4,9 +4,7 @@ from discord import Activity, ActivityType, Bot
 
 class PycordBot(Bot):
     def __init__(self, **options) -> None:
-        super().__init__(
-            **options, activity=Activity(type=ActivityType.listening, name="/hello")
-        )
+        super().__init__(**options)
         self.load_extension("pycord_bot.example_cog")
 
     async def on_ready(self) -> None:
@@ -23,7 +21,8 @@ def main() -> int:
         display_name=Color.yellow("development"),
         storage_directory=f"{__file__}/../../.botstrap_keys",
     ).run_bot(
-        PycordBot
+        PycordBot,
+        activity=Activity(type=ActivityType.listening, name="/hello"),
     )
     return 0
 
